@@ -23,7 +23,7 @@
 #include <QVariantMap>
 
 #include "CppJob.h"
-#include "PluginDllMacro.h"
+#include "DllMacro.h"
 
 #include "utils/PluginFactory.h"
 
