@@ -2,7 +2,7 @@
  *
  *   Copyright 2014-2015, Teo Mrnjavac <teo@kde.org>
  *   Copyright 2014, Aurélien Gâteau <agateau@kde.org>
- *   Copyright 2019, Adriaan de Groot <groot@kde.org>
+ *   Copyright 2019-2020, Adriaan de Groot <groot@kde.org>
  *
  *   Calamares is free software: you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -29,6 +29,7 @@
 #include "Branding.h"
 #include "GlobalStorage.h"
 #include "JobQueue.h"
+#include "partition/FileSystem.h"
 #include "utils/CalamaresUtilsGui.h"
 #include "utils/Retranslator.h"
 
@@ -37,6 +38,9 @@
 
 #include <QComboBox>
 
+using CalamaresUtils::Partition::untranslatedFS;
+using CalamaresUtils::Partition::userVisibleFS;
+
 ReplaceWidget::ReplaceWidget( PartitionCoreModule* core,
                               QComboBox* devicesComboBox,
                               QWidget* parent )
@@ -143,7 +147,7 @@ ReplaceWidget::onPartitionSelected()
     bool ok = false;
     double requiredSpaceB = Calamares::JobQueue::instance()
                             ->globalStorage()
-                            ->value( "requiredStorageGB" )
+                            ->value( "requiredStorageGiB" )
                             .toDouble( &ok ) * 1024 * 1024 * 1024;
 
     PartitionModel* model = qobject_cast< PartitionModel* >( m_ui->partitionTreeView->model() );
@@ -192,8 +196,8 @@ ReplaceWidget::onPartitionSelected()
             return;
         }
 
-        QString prettyName = tr( "Data partition (%1)" )
-                             .arg( partition->fileSystem().name() );
+        QString fsNameForUser = userVisibleFS( partition->fileSystem() );
+        QString prettyName = tr( "Data partition (%1)" ).arg( fsNameForUser );
         for ( const QString& line : osproberLines )
         {
             QStringList lineColumns = line.split( ':' );
@@ -210,13 +214,13 @@ ReplaceWidget::onPartitionSelected()
                 if ( osName.isEmpty() )
                 {
                     prettyName = tr( "Unknown system partition (%1)" )
-                                 .arg( partition->fileSystem().name() );
+                                 .arg( fsNameForUser );
                 }
                 else
                 {
                     prettyName = tr ( "%1 system partition (%2)" )
                                  .arg( osName.replace( 0, 1, osName.at( 0 ).toUpper() ) )
-                                 .arg( partition->fileSystem().name() );
+                                 .arg( fsNameForUser );
                 }
                 break;
             }
